==> FHLBBS-5.1.tgz: php/bbscom.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 require("ref.php");
 $INPFILE="inpcom.html";
 $BIBLEDIR="CBOL";
 $READHTML="http://bible.fhl.net/new/read.html";
 $ACHINESEF=array("Х@O","XJΰO","QO","ưO","өRO","ѨȰO","hvO","oO",
"հOW","հOU","CW","CU","NӤW","NӤU","H԰O","Ʀ̰O",
"HO","BO","ֽg","e","ǹD","q","HɨȮ","CQ̮","CO̫sq","H赲",
"Hz","","ҭ","q","XکȮ","","{","E","ڨ","f",
"Ӯ","{QȮ","԰",
"Ӻ֭","i֭","[֭","֭","Ϯ{","ù","Lhe","Lh","[ԤӮ",
"HҮ","̥ߤ","qù","ù{e","ù{","ӫe","ӫ","h",
"̧Q","ƧBӮ","U","oe","o","@","G","T",
"Sj","ҥܿ");
 $ACHINESES=array("","X","Q","","","","h","o",
 "W","U","W","U","NW","NU","","",
 "","B","","e","","q","","C","s","",
 "","","ҭ","","X","","","E","","f",
 "","","",
 "","i","","","{","ù","Le","L","[",
 "","","","e","","e","","h",
 "","","","e","","@","G","T",
 "S","");
 $cnum=array(50,40,27,36,34,24,21,4,31,24,22,25,29,36,10,13,
             10,42,150,31,12,8,66,52,5,48,12,14,3,9,1,4,7,3,3,3,2,14,4//¬즹
             ,28,16,24,21,28,16,16,13,6,6,4,4,5,3,6,4,3,1,13,5,5,3,5,1
             ,1,1,22);
 session_register("userid","cuser");
 if (strcasecmp($cuser->userid,"guest")==0)
        die("guest ϥγo\IЦ<a href=\"{$READHTML}\">o</a>ϥΡI");
 $bdir=sethomepath($cuser->userid);
 $bdir=$bdir."/".$BIBLEDIR;
 if (!is_dir($bdir)) mkdir("$bdir",0755);
  /*****JѼ*******/
 $fn=$_REQUEST["fn"];
 if ($fn==1)
 {
        $chineses=$_REQUEST["chineses"];
        if (!in_array($chineses,$ACHINESES)) die ("Jg~I");
        $ckey=array_search($chineses,$ACHINESES);
 	$bchap=$_REQUEST["chap"];
        $chinesef=$ACHINESEF[$ckey];
 	if ($bchap<=0 || $bchap> $cnum[$ckey]) $bchap=1;
 	$bsec=1;
 	$echap=$bchap;
 	$esec=1;
 	$buf2=$DEFDIR[$doorid].$INPFILE;
 	$data=join ('', file ($buf2));
        $data=str_replace("%userid%","$cuser->userid",$data);
        $data=str_replace("%chineses%","$chineses",$data);
        $data=str_replace("%chinesef%","$chinesef",$data);
        $data=str_replace("%bchap%","$bchap",$data);
        $data=str_replace("%echap%","$echap",$data);
        $data=str_replace("%bsec%","$bsec",$data);
        $data=str_replace("%esec%","$esec",$data);
        $data=str_replace("%txt%","",$data);
        $data=str_replace("%edmsg%","",$data);
        die($data);
 }
 if ($fn==2) //insert
 {
        $chineses=$_REQUEST["chineses"];
        if (!in_array($chineses,$ACHINESES)) die ("Jg~I");
        $ckey=array_search($chineses,$ACHINESES);
 	$bchap=$_REQUEST["bchap"];
 	$echap=$_REQUEST["echap"];
 	$bsec=$_REQUEST["bsec"];
 	$esec=$_REQUEST["esec"];
 	$txt=$_REQUEST["txt"];
 	if ($bchap<0 || $bchap> $cnum[$ckey] || $bchap > $echap) die("J`~I");
 	if ($echap<0 || $echap> $cnum[$ckey]) die("J`~I");
        if ($bsec<0 || $bsec > 176) die("J`~I");
        if ($esec<0 || $esec > 176 || $bsec > $esec) die("J`~I");
        $kckey=sprintf("%02d",$ckey);
        $kbchap=sprintf("%03d",$bchap);
        $kbsec=sprintf("%03d",$bsec);
        $kechap=sprintf("%03d",$echap);
        $kesec=sprintf("%03d",$esec);
        $buf2=$bdir."/N".$kckey."_".$kbchap."_".$kbsec."_".$kechap."_".$kesec;
        /*****˰Q@UgUh||D******/
  	$fp=fopen($buf2,"w");
  	fwrite($fp,"$txt");
  	fclose($fp);
	die ("<p><center><a href=\"/close.html\">JAo!</a></center>");
  }
 if ($fn==3) //read
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        list($PAT,$bchap,$bsec,$echap,$esec)=split ("_",$filn);
        $bchap=(int) $bchap;
        $bsec=(int) $bsec;
        $echap=(int) $echap;
        $esec=(int) $esec;
        $PAT=substr($PAT,1);
        $buf2=$bdir."/".$filn;
        if (!is_file($buf2)) die("ɮפsbI");
 	$data=join ('', file ($buf2));
        echo "<center><h2>$cuser->userid Ūg߱o</h2>\n";
        echo "<table><tr><td>";
	echo "<a href=\"/close.html\">o!</a></td>";
        echo "<td><form method=\"post\" action=\"{$PHP_SELF}\">";
        echo "<input type=\"hidden\" name=\"filn\" value=\"{$filn}\">";
        echo "<input type=\"hidden\" name=\"fn\" value=\"4\">";
        echo "<input type=\"submit\" name=\"act\" value=\"ק\"></form></td>\n";
        echo "<td><form method=\"post\" action=\"{$PHP_SELF}\">";
        echo "<input type=\"hidden\" name=\"filn\" value=\"{$filn}\">";
        echo "<input type=\"hidden\" name=\"fn\" value=\"5\">";
        echo "<input type=\"submit\" name=\"act\" value=\"R\"></form>\n</td></tr></table><p>";
        echo "<table border=1><tr><td align=\"center\">$ACHINESEF[$PAT] {$bchap}:{$bsec}-{$echap}:{$esec}";
        echo " <a href=\"{$PHP_SELF}?fn=3&filn=N{$PAT}_000_000_000_000\">I</a></td></tr>\n";
	$data=ref($data,$ACHINESES[$PAT],$bchap);
        echo "<tr><td><pre>$data</pre></td></tr></table>";
	die ("<p><a href=\"/close.html\">o!</a></center>");
 }
 if ($fn==4) //edit
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        list($PAT,$bchap,$bsec,$echap,$esec)=split ("_",$filn);
        $PAT=(int) substr($PAT,1);
        if ($PAT<0 || $PAT >65) die ("Jg~I");
        $bchap=(int) $bchap;
        $bsec=(int) $bsec;
        $echap=(int) $echap;
        $esec=(int) $esec;
        $chinesef=$ACHINESEF[$PAT];
        $chineses=$ACHINESES[$PAT];
 	$buf2=$DEFDIR[$doorid].$INPFILE;
 	$data=join ('', file ($buf2));
        $buf3=$bdir."/".$filn;
        if (!is_file($buf3)) die("ɮפsbI");
 	$txt=join ('', file ($buf3));
        unlink($buf3);
        $data=str_replace("%userid%","$cuser->userid",$data);
        $data=str_replace("%chineses%","$chineses",$data);
        $data=str_replace("%chinesef%","$chinesef",$data);
        $data=str_replace("%bchap%","$bchap",$data);
        $data=str_replace("%echap%","$echap",$data);
        $data=str_replace("%bsec%","$bsec",$data);
        $data=str_replace("%esec%","$esec",$data);
        $data=str_replace("%txt%",$txt,$data);
        $data=str_replace("%edmsg%","<font color=\"red\">`NI߱owgAYϤ]Э˦sJI</font>",$data);
        die($data);
 }
 if ($fn==5) //delete
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        $buf2=$bdir."/".$filn;
        if (!is_file($buf2)) die("ɮפsbI");
        unlink($buf2);
	die ("<center><p><a href=\"close.html\">RAo!</a></center>");
 }
?>

==> FHLBBS-5.3.tgz: php/bbscom.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 require("ref.php");
 $INPFILE="inpcom.html";
 $BIBLEDIR="CBOL";
 $READHTML="http://bible.fhl.net/new/read.html";
 $ACHINESEF=array("Х@O","XJΰO","QO","ưO","өRO","ѨȰO","hvO","oO",
"հOW","հOU","CW","CU","NӤW","NӤU","H԰O","Ʀ̰O",
"HO","BO","ֽg","e","ǹD","q","HɨȮ","CQ̮","CQ̫sq","H赲",
"Hz","","ҭ","q","XکȮ","","{","E","ڨ","f",
"Ӯ","{QȮ","԰",
"Ӻ֭","i֭","[֭","֭","Ϯ{","ù","Lhe","Lh","[ԤӮ",
"HҮ","̥ߤ","qù","ù{e","ù{","ӫe","ӫ","h",
"̧Q","ƧBӮ","U","oe","o","@","G","T",
"Sj","ҥܿ");
 $ACHINESES=array("","X","Q","","","","h","o",
 "W","U","W","U","NW","NU","","",
 "","B","","e","","q","","C","s","",
 "","","ҭ","","X","","","E","","f",
 "","","",
 "","i","","","{","ù","Le","L","[",
 "","","","e","","e","","h",
 "","","","e","","@","G","T",
 "S","");
 $cnum=array(50,40,27,36,34,24,21,4,31,24,22,25,29,36,10,13,
             10,42,150,31,12,8,66,52,5,48,12,14,3,9,1,4,7,3,3,3,2,14,4//¬즹
             ,28,16,24,21,28,16,16,13,6,6,4,4,5,3,6,4,3,1,13,5,5,3,5,1
             ,1,1,22);
 session_register("userid","cuser");
 if (strcasecmp($cuser->userid,"guest")==0)
        die("guest ϥγo\IЦ<a href=\"{$READHTML}\">o</a>ϥΡI");
 $bdir=sethomepath($cuser->userid);
 $bdir=$bdir."/".$BIBLEDIR;
 if (!is_dir($bdir)) mkdir("$bdir",0755);
  /*****JѼ*******/
 $fn=$_REQUEST["fn"];
 if ($fn==1)
 {
        $chineses=$_REQUEST["chineses"];
        if (!in_array($chineses,$ACHINESES)) die ("Jg~I");
        $ckey=array_search($chineses,$ACHINESES);
 	$bchap=$_REQUEST["chap"];
        $chinesef=$ACHINESEF[$ckey];
 	if ($bchap<=0 || $bchap> $cnum[$ckey]) $bchap=1;
 	$bsec=1;
 	$echap=$bchap;
 	$esec=1;
 	$buf2=$DEFDIR[$doorid].$INPFILE;
 	$data=join ('', file ($buf2));
        $data=str_replace("%userid%","$cuser->userid",$data);
        $data=str_replace("%chineses%","$chineses",$data);
        $data=str_replace("%chinesef%","$chinesef",$data);
        $data=str_replace("%bchap%","$bchap",$data);
        $data=str_replace("%echap%","$echap",$data);
        $data=str_replace("%bsec%","$bsec",$data);
        $data=str_replace("%esec%","$esec",$data);
        $data=str_replace("%txt%","",$data);
        $data=str_replace("%edmsg%","",$data);
        die($data);
 }
 if ($fn==2) //insert
 {
        $chineses=$_REQUEST["chineses"];
        if (!in_array($chineses,$ACHINESES)) die ("Jg~I");
        $ckey=array_search($chineses,$ACHINESES);
 	$bchap=$_REQUEST["bchap"];
 	$echap=$_REQUEST["echap"];
 	$bsec=$_REQUEST["bsec"];
 	$esec=$_REQUEST["esec"];
 	$txt=$_REQUEST["txt"];
 	if ($bchap<0 || $bchap> $cnum[$ckey] || $bchap > $echap) die("J`~I 1.");
 	if ($echap<0 || $echap> $cnum[$ckey]) die("J`~I2.");
        if ($bsec<0 || $bsec > 176) die("J`~I3.");
        if ($esec<0 || $esec > 176) die("J`~I4.");
        $kckey=sprintf("%02d",$ckey);
        $kbchap=sprintf("%03d",$bchap);
        $kbsec=sprintf("%03d",$bsec);
        $kechap=sprintf("%03d",$echap);
        $kesec=sprintf("%03d",$esec);
        $buf2=$bdir."/N".$kckey."_".$kbchap."_".$kbsec."_".$kechap."_".$kesec;
        /*****˰Q@UgUh||D******/
  	$fp=fopen($buf2,"w");
  	fwrite($fp,"$txt");
  	fclose($fp);
	echo "<p><center><a href=\"/close.html\">JAo!</a><p>";
	die ("<a href=\"{$PHP_SELF}?fn=1&chineses={$chineses}&chap={$echap}\">~J</a></center>");
  }
 if ($fn==3) //read
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        list($PAT,$bchap,$bsec,$echap,$esec)=split ("_",$filn);
        $bchap=(int) $bchap;
        $bsec=(int) $bsec;
        $echap=(int) $echap;
        $esec=(int) $esec;
        $PAT=substr($PAT,1);
        $buf2=$bdir."/".$filn;
        if (!is_file($buf2)) die("ɮפsbI");
 	$data=join ('', file ($buf2));
        echo "<center><h2>$cuser->userid Ūg߱o</h2>\n";
        echo "<table><tr><td>";
	echo "<a href=\"/close.html\">o!</a></td>";
        echo "<td><form method=\"post\" action=\"{$PHP_SELF}\">";
        echo "<input type=\"hidden\" name=\"filn\" value=\"{$filn}\">";
        echo "<input type=\"hidden\" name=\"fn\" value=\"4\">";
        echo "<input type=\"submit\" name=\"act\" value=\"ק\"></form></td>\n";
        echo "<td><form method=\"post\" action=\"{$PHP_SELF}\">";
        echo "<input type=\"hidden\" name=\"filn\" value=\"{$filn}\">";
        echo "<input type=\"hidden\" name=\"fn\" value=\"5\">";
        echo "<input type=\"submit\" name=\"act\" value=\"R\"></form>\n</td></tr></table><p>";
        echo "<table border=1><tr><td align=\"center\">$ACHINESEF[$PAT] {$bchap}:{$bsec}-{$echap}:{$esec}";
        echo " <a href=\"{$PHP_SELF}?fn=3&filn=N{$PAT}_000_000_000_000\">I</a></td></tr>\n";
	$data=ref($data,$ACHINESES[$PAT],$bchap);
        echo "<tr><td><pre>$data</pre></td></tr></table>";
	die ("<p><a href=\"/close.html\">o!</a></center>");
 }
 if ($fn==4) //edit
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        list($PAT,$bchap,$bsec,$echap,$esec)=split ("_",$filn);
        $PAT=(int) substr($PAT,1);
        if ($PAT<0 || $PAT >65) die ("Jg~I");
        $bchap=(int) $bchap;
        $bsec=(int) $bsec;
        $echap=(int) $echap;
        $esec=(int) $esec;
        $chinesef=$ACHINESEF[$PAT];
        $chineses=$ACHINESES[$PAT];
 	$buf2=$DEFDIR[$doorid].$INPFILE;
 	$data=join ('', file ($buf2));
        $buf3=$bdir."/".$filn;
        if (!is_file($buf3)) die("ɮפsbI");
 	$txt=join ('', file ($buf3));
        unlink($buf3);
        $data=str_replace("%userid%","$cuser->userid",$data);
        $data=str_replace("%chineses%","$chineses",$data);
        $data=str_replace("%chinesef%","$chinesef",$data);
        $data=str_replace("%bchap%","$bchap",$data);
        $data=str_replace("%echap%","$echap",$data);
        $data=str_replace("%bsec%","$bsec",$data);
        $data=str_replace("%esec%","$esec",$data);
        $data=str_replace("%txt%",$txt,$data);
        $data=str_replace("%edmsg%","<font color=\"red\">`NI߱owgAYϤ]Э˦sJI</font>",$data);
        die($data);
 }
 if ($fn==5) //delete
 {
 	$filn=$_REQUEST["filn"];
	if ((strrchr($filn,'/')!==false)||(strrchr($filn,'.')!==false)) //ȬOhacker
           die ("<h1>AOhackerܡH</h1><p>\n");
        $buf2=$bdir."/".$filn;
        if (!is_file($buf2)) die("ɮפsbI");
        unlink($buf2);
	die ("<center><p><a href=\"close.html\">RAo!</a><p>");
 }
?>
